/* 
* -cr_beg-
* ********************************************************************
* IBM Confidential
* OCO Source Materials
* 5724-U38, 5724-U39, 5724-U48, 5655-V17, 5655-V19, 5655-V35, 5655-V37
* Copyright IBM Corp. 2011,2013
* The source code for this program is not published or otherwise
* divested of its trade secrets, irrespective of what has
* been deposited with the U.S. Copyright Office.
* ********************************************************************
* -cr_end-
*/ 
/*----------------------------------------------------------------------------
File Name:  ODPPCmnOprH.h

Purpose:    Provides the Operands suported by all the providers

Functions:

   Name              Purpose

Structures:

   Name              Purpose

Author:
   Ritesh Tandon     IBM ISL 29/Dec/2009
----------------------------------------------------------------------------*/
/****************************************************************************
 * RTC/JAZZ change log
 *
 *
 * 15 Apr 2012 LarryB : 2.1.0.4 WI 30223
 * Fixed: number of areas where single byte EBCDIC was not getting
 * processed properly in a z/OS environment
 *
 ****************************************************************************/
#ifndef __OODPPCMNOPRH__
#define __OODPPCMNOPRH__

/* these are common separators whichever service uses it
   these can be used operands such as ODPP_OPR_NID_FR_SEP
   if a service provider wants to use Separators then it
   should declare a Seprator operand */
#define ODPP_NO_SEP                             1
#define ODPP_SEP_USESOURCE                      2
#define ODPP_SEP_DOT                            4
#define ODPP_SEP_DASH                           8
#define ODPP_SEP_SPACE                          16
#define ODPP_SEP_UNDERSCORE                     32

#define ODPP_TRACE_ERROR                        1
#define ODPP_TRACE_WARNING                      2
#define ODPP_TRACE_INFO                         4


/* Request range Upto 0x0FFF. Approx 512 values */
#define REQUESTBASE                             0x0E01
#define ODPP_REQ_SRC_COL_INDEX                  REQUESTBASE + 0
#define ODPP_REQ_DEST_COL_INDEX                 REQUESTBASE + 1
#define ODPP_REQ_DEST_DATATYPE                  REQUESTBASE + 2
#define ODPP_REQ_DEST_FIELD_INFO                REQUESTBASE + 3

#define OPERANDBASE                             0x1000
/* Range for common framework provided operands 0x1000 to 0x1800 */
/* First 1024 values reserved for common Operands, next 1024 reserved
   for common operand values */
/* Range for operands 0x1000 to 0x13FF */

/* Common Operands used by the ODPP */
#define ODPP_OPR_SWITCH_LITERAL                 OPERANDBASE + 1
#define ODPP_OPR_SWITCH_FUNCTION                OPERANDBASE + 2
#define ODPP_OPR_SWITCH_COLINDEX                OPERANDBASE + 3
#define ODPP_OPR_SWITCH_COLNAME                 OPERANDBASE + 4
#define ODPP_OPR_SWITCH_NA                      OPERANDBASE + 5
#define ODPP_OPR_PARTS                          OPERANDBASE + 6
#define ODPP_OPR_SOURCE_COLINDEX                OPERANDBASE + 7
#define ODPP_OPR_SOURCE_COLNAME                 OPERANDBASE + 8
#define ODPP_OPR_SEPARATOR                      OPERANDBASE + 9
#define ODPP_OPR_FLAGS                          OPERANDBASE + 10
#define ODPP_OPR_METHOD                         OPERANDBASE + 11
#define ODPP_OPR_TRACEPATH                      OPERANDBASE + 12
#define ODPP_OPR_TRACELEVEL                     OPERANDBASE + 13
#define ODPP_OPR_DATE                           OPERANDBASE + 14
#define ODPP_OPR_TIME                           OPERANDBASE + 15
#define ODPP_OPR_TIME_EX                        OPERANDBASE + 16
#define ODPP_OPR_TIMESTAMP                      OPERANDBASE + 17
#define ODPP_OPR_TIMESTAMP_EX                   OPERANDBASE + 18
#define ODPP_OPR_DISCARD_LIMIT                  OPERANDBASE + 19
#define ODPP_OPR_RETRY_FAILED                   OPERANDBASE + 20
#define ODPP_OPR_SOURCE_COLS                    OPERANDBASE + 21
#define ODPP_OPR_ERRORFILE_PATH                 OPERANDBASE + 22
#define ODPP_OPR_SOURCE_DATE_FORMAT             OPERANDBASE + 23
#define ODPP_OPR_DEST_DATE_FORMAT               OPERANDBASE + 24
#define ODPP_OPR_DEST_DATATYPE                  OPERANDBASE + 25
#define ODPP_OPR_ERROR_MSG_LANGUAGE             OPERANDBASE + 26
#define ODPP_OPR_MAX_NUMBER_OF_TRACE_FILES      OPERANDBASE + 27
#define ODPP_OPR_LIC_FILES_PATH                 OPERANDBASE + 28
#define ODPP_OPR_FRMW_ERR_MSG_BUF               OPERANDBASE + 29
//Service provider path as supplied by user
//If not specific libraries will be serached according to
//the platform specific search order.
#define ODPP_OPR_LIB_PATH                       OPERANDBASE + 30
#define ODPP_OPR_TRACE_NAME                     OPERANDBASE + 31
//Hash Library operands
#define ODPP_OPR_HASH_ALGORITHM                 OPERANDBASE + 32 //1020:4128
#define ODPP_OPR_HASH_SEED_HMAC                 OPERANDBASE + 33 //1021:4129

#define ODPP_OPR_USE_SUCCESS_WITH_INFO          OPERANDBASE + 34 //1022:4130

/* Range for common operand flags/values 0x1400 to 0x1800 */
#define VALUEBASE                               0x1400 //5120
/* Common Operand Value/Flag Defines*/
#define ODPP_METHOD_MASK                        VALUEBASE + 6
#define ODPP_METHOD_RANDOM                      VALUEBASE + 7
#define ODPP_METHOD_DEFAULT                     VALUEBASE + 8
#define ODPP_TRACE_PATH_DEFAULT                 VALUEBASE + 9
/* Error message Language value defines. Reserve approx 20 values
   for the languages. Although reserving does not make any difference
   it is done just to keep language defines at one place */
#define ODPP_ERR_MSG_LANG_EN                    VALUEBASE + 10
/*#define ODPP_ERR_MSG_LANG_JP                    VALUEBASE + 11

#define ODPP_ERR_MSG_LANG_<language>             VALUEBASE + 29 */
/* END: Error message Language value defines. */
//Hash Library operand value defines
//Values for ODPP_OPR_HASH_ALGORITHM
#define ODPP_HASH_ALGORITHM_NATIVE              VALUEBASE + 30 //141E:5150
#define ODPP_HASH_ALGORITHM_SHA256              VALUEBASE + 31 //141F:5151

/*===========================================================================
   FLAGs values
   These values need to a shift value from 1. The max allowed are 15 flag
   values that can be supplied at a time
 ==========================================================================*/
#define ODPP_FLAG_VALIDATE_INPUT                1
#define ODPP_FLAG_IGNORE_INVALID                2

/*==========================================================
   Provider specific operands and thier values
==========================================================*/
/*==========================================================
                        NID
 Range for NID operands/flags/values from  0x1801 to 0x1964.
 Max 356 values. 256 for Operands and 100 for values
 ==========================================================*/
/* Range for NID operands 0x1801 to 0x1900. Max 256 values */
#define NIDOPERANDBASE                          0x1801

/* Operands for PARTS for various NIDs */
#define ODPP_OPR_NID_FR_PARTS                   NIDOPERANDBASE + 0
#define ODPP_OPR_NID_ES_PARTS                   NIDOPERANDBASE + 1
#define ODPP_OPR_NID_IT_PARTS                   NIDOPERANDBASE + 2
#define ODPP_OPR_NID_UK_PARTS                   NIDOPERANDBASE + 3
#define ODPP_OPR_NID_US_PARTS                   NIDOPERANDBASE + 4
#define ODPP_OPR_NID_CA_PARTS                   NIDOPERANDBASE + 5

/* Operands for SEPs for various NIDs */
#define ODPP_OPR_NID_FR_SEP                     NIDOPERANDBASE + 6
#define ODPP_OPR_NID_ES_SEP                     NIDOPERANDBASE + 7
#define ODPP_OPR_NID_IT_SEP                     NIDOPERANDBASE + 8
#define ODPP_OPR_NID_UK_SEP                     NIDOPERANDBASE + 9
#define ODPP_OPR_NID_US_SEP                     NIDOPERANDBASE + 10
#define ODPP_OPR_NID_CA_SEP                     NIDOPERANDBASE + 11

/* Operands for FLAGS for various NIDs */
#define ODPP_OPR_NID_UK_FLAGS                   NIDOPERANDBASE + 12
#define ODPP_OPR_NID_US_FLAGS                   NIDOPERANDBASE + 13

/* these values are for FR operand ODPP_OPR_NID_FR_PARTS only */
#define ODPP_FR_PARTS_MASK_SEX		            1
#define ODPP_FR_PARTS_MASK_YEAR		            2
#define ODPP_FR_PARTS_MASK_MONTH		            4
#define ODPP_FR_PARTS_MASK_DEPT		            8
#define ODPP_FR_PARTS_MASK_COMMUNE	            16

/* these values are for IT operand ODPP_OPR_NID_IT_PARTS only */
#define ODPP_IT_PARTS_MASK_NAME		            1
#define ODPP_IT_PARTS_MASK_BIRTH_DATE		      2
#define ODPP_IT_PARTS_MASK_REGION		         4

/* these values are for UK operand ODPP_OPR_NID_UK_PARTS only */
#define ODPP_UK_PARTS_MASK_PREFIX		         1

/* these values are for UK operand ODPP_OPR_NID_UK_FLAGS only */
#define ODPP_FLAG_UK_FORM_3_PART		            1
#define ODPP_FLAG_UK_FORM_5_PART		            2

/* these values are for CA operand ODPP_OPR_NID_CA_PARTS only */
#define ODPP_CA_PARTS_MASK_HEAD		            1

/* these values are for US operand ODPP_OPR_NID_US_FLAGS only */
#define ODPP_FLAG_US_RANDOM                     1
#define ODPP_FLAG_USE_DIST_TABLE                2
#define ODPP_FLAG_USE_ZOS_TABLE                 4

/* Range for NID values 0x1901 to 0x1964 Max. 100 values */
#define NIDVALUEBASE                            0x1901



/*==========================================================
                        CCN
  Range for CCN operands/flags/values from  0x1965 to 0x1985.
  Max 32 values. 16 for Operands and 16 for operand values
 ==========================================================*/
/* Range for ccn operands 0x1965 to 0x1975. Max 16 values  */
#define CCNOPERANDBASE                          0x1965
/* Operand for CCN specific Flags */
#define ODPP_OPR_CCN_FLAGS                      CCNOPERANDBASE + 0

/* CCN Flags for CCN operand ODPP_OPR_CCN_FLAGS. Max 15 Flags */
#define ODPP_FLAG_CCN_RANDOM                    1
#define ODPP_FLAG_CCN_ISSUER6                   2

/* Range for ccn values 0x1976 to 0x1985. Max 16 values */
#define CCNVALUEBASE                            0x1976


/*==========================================================
                        EMAIL
  Range for EML operands/flags/values from  0x1986 to 0x19E5.
  Max 96 values. 32 for Operands and 64 for operand values
  ==========================================================*/
/* Range for EML operands from  0x1986 to 0x19A5 Max 32 values*/
#define EMLOPERANDBASE                          0x1986
#define ODPP_OPR_EML_FLAGS                      EMLOPERANDBASE + 0 //6534
#define ODPP_OPR_EML_DOMAIN                     EMLOPERANDBASE + 1 //6535
#define ODPP_OPR_EML_NAME1COL_INDEX             EMLOPERANDBASE + 2 //6536
#define ODPP_OPR_EML_NAME2COL_INDEX             EMLOPERANDBASE + 3 //6537
#define ODPP_OPR_EML_USERPRFX                   EMLOPERANDBASE + 4 //6538
#define ODPP_OPR_EML_SEPARATOR                  EMLOPERANDBASE + 5 //6539
#define ODPP_OPR_EML_HASHSEED                   EMLOPERANDBASE + 6 //6540
#define ODPP_OPR_EML_HASHDOMAIN                 EMLOPERANDBASE + 7 //6541
#define ODPP_OPR_EML_NAME1COL_NAME              EMLOPERANDBASE + 8 //6542
#define ODPP_OPR_EML_NAME2COL_NAME              EMLOPERANDBASE + 9 //6543

/* These values are for EML operand ODPP_OPR_EML_FLAGS only. Max 15 flags only */
#define ODPP_EML_FLAG_INITIAL                   1
#define ODPP_EML_FLAG_LOWER                     2
#define ODPP_EML_FLAG_UPPER                     4
#define ODPP_EML_FLAG_HASH_ENABLED              8

/* Range for EML flags/values from  0x19A6 to 0x19E5. Max 64 values*/
#define EMLVALUEBASE                            0x19A6
/* These vallues are applicable for Operand ODPP_OPR_EML_HASHDOMAIN only */
#define ODPP_EML_DOMAIN_KEEP                    EMLVALUEBASE + 0 //6566
#define ODPP_EML_DOMAIN_REGISTERED              EMLVALUEBASE + 1 //6567
#define ODPP_EML_DOMAIN_UNREGISTERED            EMLVALUEBASE + 2 //6568


/*==========================================================
                        COL
  Range for COL operands/flags/values from  0x19E6 to 0x1A0F
  Max 41 values. 16 for Operands and 25 for operand values
  ==========================================================*/
/* Range for COL operands from  0x19E6 to 0x19F5. Max 16 values */
#define COLOPERANDBASE                          0x19E6
#define ODPP_OPR_COL_MASK                       COLOPERANDBASE +  0
#define ODPP_OPR_COL_VARSEED                    COLOPERANDBASE +  1
#define ODPP_OPR_COL_LITSEED                    COLOPERANDBASE +  2
#define ODPP_OPR_COL_RNDSEED                    COLOPERANDBASE +  3
#define ODPP_OPR_COL_COPY                       COLOPERANDBASE +  4
#define ODPP_OPR_COL_LENGTH                     COLOPERANDBASE +  5
#define ODPP_OPR_COL_NUM                        COLOPERANDBASE +  6
#define ODPP_OPR_COL_TRIM                       COLOPERANDBASE +  7
#define ODPP_OPR_COL_BINARY                     COLOPERANDBASE +  8

/* Range for COL flags/values from 0x19F6 to 0x1A0F. Max 26 values */
#define COLVALUEBASE                            0x19F6
#define ODPP_COL_MASK_UNIQUE                    COLVALUEBASE + 0
#define ODPP_COL_MASK_HASH                      COLVALUEBASE + 1
#define ODPP_COL_LENGTH_MAX                     COLVALUEBASE + 2
#define ODPP_COL_BINARY_SCALED                  COLVALUEBASE + 3

/*==========================================================
                        LOOKUP
  Range for LOOKUP operands/flags/values from 0x1A10(-0x1A20-) to 1A39
  17 Values for Operands and 25 for operand values
  ==========================================================*/
/* Range for LOOKUP operands from  0x1A10(6672) to 0x1A2A(6698).Max 27 values*/
#define LOOKUPOPERANDBASE                       0x1A10  /* 6672 */

#define ODPP_OPR_LOOKUP_SEARCH_COLS             ODPP_OPR_SOURCE_COLS
#define ODPP_OPR_SRC_COL_OPERATOR               LOOKUPOPERANDBASE + 0 /*1A10:6672*/
#define ODPP_OPR_LDS_ID                         LOOKUPOPERANDBASE + 1
#define ODPP_OPR_LDS_LIB                        LOOKUPOPERANDBASE + 2
#define ODPP_OPR_LOOKUP_REPLACE_COLS            LOOKUPOPERANDBASE + 3
#define ODPP_OPR_LOOKUP_TRIM_CHARS              LOOKUPOPERANDBASE + 4
#define ODPP_OPR_LOOKUP_SEED                    LOOKUPOPERANDBASE + 5
#define ODPP_OPR_LOOKUP_LIMIT                   LOOKUPOPERANDBASE + 6
#define ODPP_OPR_LOOKUP_FLAGS                   LOOKUPOPERANDBASE + 7
#define ODPP_OPR_LOOKUP_HASH_SEQ_COL_NAME       LOOKUPOPERANDBASE + 8
#define ODPP_OPR_LKP_CACHE_TEMP_PATH            LOOKUPOPERANDBASE + 9
#define ODPP_OPR_RND_LKP_TEMP_PATH              ODPP_OPR_LKP_CACHE_TEMP_PATH
#define ODPP_OPR_LKP_CACHE_MEM_THRESHHOLD       LOOKUPOPERANDBASE + 10
#define ODPP_OPR_LKP_PRESERVE_NULL              LOOKUPOPERANDBASE + 11
#define ODPP_OPR_LKP_PRESERVE_BLANK             LOOKUPOPERANDBASE + 12
#define ODPP_OPR_LKP_PRESERVE_ZEROLEN           LOOKUPOPERANDBASE + 18
#define ODPP_OPR_LKP_PRESERVE_NOTFOUND          LOOKUPOPERANDBASE + 19 /*1A23:6691*/
#define ODPP_OPR_LKP_SPL_HASH_VAL_SINGLE_COL_NULL        LOOKUPOPERANDBASE + 20
#define ODPP_OPR_LKP_SPL_HASH_VAL_SINGLE_COL_BLANK       LOOKUPOPERANDBASE + 21
#define ODPP_OPR_LKP_SPL_HASH_VAL_SINGLE_COL_ZEROLEN     LOOKUPOPERANDBASE + 22
#define ODPP_OPR_LKP_SPL_HASH_VAL_MULTI_COL_NULL         LOOKUPOPERANDBASE + 23
#define ODPP_OPR_LKP_SPL_HASH_VAL_MULTI_COL_BLANK        LOOKUPOPERANDBASE + 24
#define ODPP_OPR_LKP_SPL_HASH_VAL_MULTI_COL_ZEROLEN      LOOKUPOPERANDBASE + 25
#define ODPP_OPR_LKP_SPL_HASH_VAL_MULTI_COL_MIXED        LOOKUPOPERANDBASE + 26/*1A2A:6698*/
/*==========================================================
Range 0x1A8E(6798) to 1AA6(6822) 25 additional values 
allocted to Lookup service provider. See below
========================================================*/

/* DB2 LDS implementation specific operands */
#define ODPP_OPR_LDS_USERNAME                   LOOKUPOPERANDBASE + 13
#define ODPP_OPR_LDS_PASSWORD                   LOOKUPOPERANDBASE + 14
#define ODPP_OPR_LDS_CONN_STRING                LOOKUPOPERANDBASE + 15
#define ODPP_OPR_LDS_SCHEMA                     LOOKUPOPERANDBASE + 16
#define ODPP_OPR_LDS_CODEPAGE                   LOOKUPOPERANDBASE + 17
/* DB2 LDS implementation specific operands */


/* Range for LOOKUP flags/values from 0x1A2B to 0x1A39. Max 15 values */
#define LOOKVALUEBASE                           0x1A2B
#define ODPP_LDS_OPERATOR_AND                   LOOKVALUEBASE + 0
#define ODPP_LDS_OPERATOR_OR                    LOOKVALUEBASE + 1
#define ODPP_LDS_OPERATOR_YES                   LOOKVALUEBASE + 2
#define ODPP_LDS_OPERATOR_NO                    LOOKVALUEBASE + 3

/* Value for the operand ODPP_OPR_LDS_LIB to use standard DB2 lib */
#define ODPP_LDS_DB2_LUW                    LOOKVALUEBASE + 4
// LarryB: BEGIN: WI 30223
/* Value for the operand ODPP_OPR_LDS_LIB to use z/OS DB2 lib */
#define ODPP_LDS_DB2_ZOS                    LOOKVALUEBASE + 5
// Larry B: END: WI 30223
#define ODPP_LDS_ORACLE                     LOOKVALUEBASE + 6

/* These values are for operand ODPP_OPR_LOOKUP_FLAGS only. Max 31 flags only */
#define ODPP_FLAG_LOOKUP_CACHE                  1
#define ODPP_FLAG_LOOKUP_NOCACHE                2
#define ODPP_FLAG_LOOKUP_SRC_UPR                4
#define ODPP_FLAG_LOOKUP_HASH                   8
#define ODPP_FLAG_LOOKUP                        16
#define ODPP_FLAG_LOOKUP_USE_MEM_CACHE_ONLY     32

/*==========================================================
                        HASH
  Range for HASH operands/flags/values from 0x1A3A (-0x1A4A-0x1A4B-) to 1A63
  17 Values for Operands and 25 for operand values
  ========================================================*/
/* Range for HASH operands from  0x1A3A (6714) to 1A54 (6740). Max 27 values */
#define HASHOPERANDBASE                         0x1A3A /*6714*/
//#define ODPP_OPR_HASH_SOURCE_COLS               HASHOPERANDBASE + 0
#define ODPP_OPR_HASH_MAXVALUE                  HASHOPERANDBASE + 2 /*1A3C:6716*/
#define ODPP_OPR_HASH_SEED_LIT                  HASHOPERANDBASE + 3
#define ODPP_OPR_HASH_SEED_ENV                  HASHOPERANDBASE + 4
#define ODPP_OPR_HASH_SEED_RANDOM               HASHOPERANDBASE + 5
#define ODPP_OPR_HASH_SEED_COL                  HASHOPERANDBASE + 6
#define ODPP_OPR_HASH_DEST_COL                  HASHOPERANDBASE + 7
#define ODPP_OPR_HASH_TRIM_CHARS                HASHOPERANDBASE + 8
#define ODPP_OPR_HASH_SRC_COL_SEP               HASHOPERANDBASE + 9
#define ODPP_OPR_HASH_FLAGS                     HASHOPERANDBASE + 10
#define ODPP_OPR_HASH_ALGO                      HASHOPERANDBASE + 11
#define ODPP_OPR_HASH_SPL_HASH_VAL_SINGLE_COL_NULL      HASHOPERANDBASE + 12
#define ODPP_OPR_HASH_SPL_HASH_VAL_SINGLE_COL_BLANK     HASHOPERANDBASE + 13
#define ODPP_OPR_HASH_SPL_HASH_VAL_SINGLE_COL_ZEROLEN   HASHOPERANDBASE + 14
#define ODPP_OPR_HASH_SPL_HASH_VAL_MULTI_COL_NULL       HASHOPERANDBASE + 15
#define ODPP_OPR_HASH_SPL_HASH_VAL_MULTI_COL_BLANK      HASHOPERANDBASE + 16 /*1A4A:6730*/
#define ODPP_OPR_HASH_SPL_HASH_VAL_MULTI_COL_ZEROLEN    HASHOPERANDBASE + 17
#define ODPP_OPR_HASH_SPL_HASH_VAL_MULTI_COL_MIXED      HASHOPERANDBASE + 18 /*1A4C:6732*/

/* Range for HASH values from  0x1A55(6741) to 0x1A63(6755). Max 15 values */
#define HASHVALUEBASE                           0x1A55
#define ODPP_METHOD_HASH                        ODPP_METHOD_MASK
#define ODPP_HASH_ALGO_1                        HASHVALUEBASE + 0
#define ODPP_NO_RETRY_FAILED                    HASHVALUEBASE + 1
#define ODPP_RETRY_FAILED                       HASHVALUEBASE + 2

/* Hash Provider Specific Info Requests Codes
   Specify in reverse order. Max being 24 i.e. the limit
   for operand values */
#define ODPP_HASH_REQ_SEED_COL_INDEX            HASHVALUEBASE + 13
#define ODPP_HASH_REQ_MAX_HASH_VALUE            HASHVALUEBASE + 14
//#define ODPP_HASH_REQ_XXXXXXXXXXXXXX            HASHVALUEBASE + 14

/* These values are for operand ODPP_OPR_HASH_FLAGS only. Max 31 flags only */
#define HASH_FLAG_SRC_TO_UPPER                  1



/*==========================================================
                        AGE
  Range for AGE operands/flags/values from 0x1A64 (-0x1A74-0x1A75-) to 1A8D
  17 Values for Operands and 25 for operand values
  ========================================================*/
/* Range for AGE operands from  0x1A64 to 0x1A74. Max 17 values */
#define AGEOPERANDBASE                          0x1A64 /* 6756 */
#define ODPP_OPR_AGE_YEAR                       AGEOPERANDBASE + 0 /* 6756 */
#define ODPP_OPR_AGE_MONTH                      AGEOPERANDBASE + 1 /* 6757 */
#define ODPP_OPR_AGE_WEEK                       AGEOPERANDBASE + 2 /* 6758 */
#define ODPP_OPR_AGE_DAY                        AGEOPERANDBASE + 3 /* 6759 */
#define ODPP_OPR_AGE_SPECIFIC_YEAR              AGEOPERANDBASE + 4 /* 6760 */
#define ODPP_OPR_AGE_CENTURY_PIVOT              AGEOPERANDBASE + 5 /* 6761 */

/* Range for AGE values from  0x1A75 to 0x1A8D. Max 25 values */
#define AGEVALUEBASE                            0x1A75


/*==========================================================
                  Lookup Service Provider
  Range 0x1A8E(6798) to 1AA6(6822) 25 values allocted to
  Lookup service provider
  ========================================================*/
#define LOOKUPOPERANDBASE_EXT                            0x1A8E   //6798
#define ODPP_OPR_LKP_NOT_FOUND_REPLACEMENT_ROW           LOOKUPOPERANDBASE_EXT + 0/*1A8E:6798*/


/*==========================================================
                  Data Swapping Service Provider
  Range 0x1AA7(6823) to 0x1AD8(6872) 50 values, for 
  operands/flags/values from allocated to swapping service 
  providers
  ========================================================*/
#define SWAPOPERANDBASE                          0x1AA7              /* 6823 */
#define ODPP_OPR_SWAP_FIELD_INDICES              SWAPOPERANDBASE + 0 /* 6823 */
#define ODPP_OPR_SWAP_FIELD_NAMES                SWAPOPERANDBASE + 1 /* 6824 */
#define ODPP_OPR_SWAP_SEED                       SWAPOPERANDBASE + 2 /* 6825 */
#define ODPP_OPR_SWAP_LOCKED                     SWAPOPERANDBASE + 3 /* 6826 */
#define ODPP_OPR_SWAP_RATE                       SWAPOPERANDBASE + 4 /* 6827 */
#define ODPP_OPR_SWAP_CONTROL_ATTR	             SWAPOPERANDBASE + 5 /* 6828 */
#define ODPP_OPR_SWAP_CLASSIFIER	                SWAPOPERANDBASE + 6 /* 6829 */
#define ODPP_OPR_SWAP_CLASSIFIER_PARAMS          SWAPOPERANDBASE + 7 /* 6830 */
#define ODPP_OPR_SWAP_BLOCK_SIZE                 SWAPOPERANDBASE + 8 /* 6831 */


// #define ODPP_OPR_SWAP_PRESERVE_INVALID           SWAPOPERANDBASE + 4 /* 6827 */

/*==========================================================
                  ODPP Hash Library
  Range 0x1AD9(6873) to 0x1B0A(6922) 50 values, for 
  operands/flags/values of Hash Library
  ========================================================*/

/*==========================================================
                  <NEXT Service Provider>
  Range for <NEXT> operands/flags/values from 0x1B0B(6923) ...

  ========================================================*/

#endif //__OODPPCMNOPRH__


